@@ -1,8 +1,8 @@
 import sys
-from .kerasmodel import KerasModel
+from .kerasmodel import KerasModel,train_model
 from .summary import summary
 try:
     from .lightmodel import LightModel 
 except Exception:
     print("torchkeras.LightModel can't be used!",file = sys.stderr)
-__version__='3.2.5'
+__version__='3.3.0'
